# Awkward Array documentation


% TODO mention left side-bar
:::::{grid} 1 1 2 2
:class-container: intro-grid text-center

::::{grid-item-card} 
:columns: 12

Awkward Array is a library for **nested, variable-sized data**, including arbitrary-length lists, records, mixed types, and missing data, using **NumPy-like idioms**.

:::{image} https://img.shields.io/conda/vn/conda-forge/awkward?style=for-the-badge&color=brightgreen&logo=condaforge
:alt: Conda (channel only)
:target: https://anaconda.org/conda-forge/awkward
:class: shield-badge
:::

:::{image} https://img.shields.io/pypi/v/awkward?style=for-the-badge&logo=pypi
:alt: PyPI
:target: https://pypi.org/project/awkward
:class: shield-badge
:::

:::{image} https://img.shields.io/badge/GitHub-scikit--hep%2Fawkward-lightgrey?style=for-the-badge&logo=GitHub
:alt: GitHub
:target: https://github.com/scikit-hep/awkward
:class: shield-badge
:::

% Unfortunately, `target` does not support document references
:::{image} https://img.shields.io/badge/-Try%20It%21-orange?style=for-the-badge
:alt: Try It!
:target: getting-started/try-awkward-array.html
:class: shield-badge
:::

::::

::::{grid-item-card} 
:link-type: doc
:link: getting-started/index

{fas}`running`

Getting started 
^^^^^^^^^^^^^^^
New to *Awkward Array*? Unsure what it can be used for? Check out the getting started guides. They contain an introduction to *Awkward Array's* features and links to additional help.
   

::::

:::{grid-item-card}
:link-type: doc
:link: user-guide/index

{fas}`book-open`

User guide
^^^^^^^^^^

The user guide provides in-depth information on the key concepts of Awkward Array with useful background information and explanation.

:::

:::{grid-item-card}
:link-type: doc
:link: reference/index

{fas}`code`

API reference
^^^^^^^^^^^^^

The reference guide contains a detailed description of the functions, modules, and objects included in Awkward Array. The reference describes how the methods work and which parameters can be used. It assumes that you have an understanding of the key concepts.

:::

:::{grid-item-card}
:link: https://github.com/scikit-hep/awkward/blob/main/CONTRIBUTING.md

{fas}`terminal`

Contributor's guide
^^^^^^^^^^^^^^^^^^^
Spotted a typo in the documentation? Want to add to the codebase? The contributing guidelines will guide you through the process of improving Awkward Array.

:::

:::{grid-item-card} 
:columns: 12
:link: https://awkward-array.org/doc/1.10/api-reference.html
:class-card: admonition warning

{fas}`history` Need the documentation for version 1 of Awkward Array? Click this card.
::::
    
:::::
